@@ -26,6 +26,10 @@ except ImportError:
     warnings.warn("Please install 'requests'. 'pip install requests'")
     sys.exit(1)
 
+import re
+
+
+pattern = re.compile(r"""(?P<propertyName>(?=^)\w[\s\w,]+)(?(1):)(?:\s|\n)?(?P<propertyData>[\W\w\s]+)""", re.MULTILINE)
 
 logHandler = handlers.RotatingFileHandler('tfs.log', maxBytes=20 * 1024 * 1024, backupCount=10)
 logging.basicConfig(
@@ -139,7 +143,7 @@ CACHE_FILE = os.path.join(os.path.dirname(os.path.abspath(__file__)), '.testbrai
 logging.debug("CACHE_FILE: {}".format(CACHE_FILE))
 
 login_details = ""
-
+print("reset login details")
 
 class FileLockException(Exception):
     pass
@@ -290,7 +294,7 @@ def get_all_changesets_rest_api():
     def get_data():
         r = requests.get(str.format(get_changesets_url,
                                     organization, project, len(arr)), auth=('Khalil Mohammad Mirza', '263ztlyieakewwcgeu75xivdwpkhtzkycbgy555f5camihzfdzaq'))
-        if r.status_code is 200:
+        if r.status_code == 200:
             json = r.json()
             count = json['count']
             value = json['value']
@@ -352,52 +356,54 @@ def get_branch_list():
 def get_last_branch_changeSet(branch, numberOfChangets):
     output = execute(MoveToMainDirectory + TF_Branches_History.format(branch) + (
         "" if numberOfChangets == None else " /stopafter:{}".format(numberOfChangets)))
+
     changeSetList = []
-    changeSetDict = {}
-    propertyName = ""
-    propertyData = ""
-    needPropertData = False
-    itemsDict = {}
-    isItemDict = False
-    changeSetDict["branch"] = branch
+    # changeSetDict = {}
+    # propertyName = ""
+    # propertyData = ""
+    # needPropertData = False
+    # itemsDict = {}
+    # isItemDict = False
+    # changeSetDict["branch"] = branch
 
-    splits = output.split("\n")[1:]
-    for split in splits:
-        split = split.strip()
-        if split:
-            if split == "Items:":
-                isItemDict = True
-                continue
+    output_list = [item for item in output.split("-" * 79 + '\n\n') if item]
 
-            if all(character == '-' for character in split):
-                changeSetDict["items"] = itemsDict
-                changeSetList.append(changeSetDict)
-                isItemDict = False
-                changeSetDict = {}
-                itemsDict = {}
-                changeSetDict["branch"] = branch
-                continue
+    for changeset_raw in output_list:
+        changeSetDict = {}
+        itemsDict = {}
 
-            if not isItemDict:
-                if needPropertData:
-                    propertyData = split
-                    needPropertData = False
-                else:
-                    index = split.find(":")
-                    propertyName = split[:index]
-                    propertyData = split[index + 2:].strip()
-                    if not propertyData:
-                        needPropertData = True
-                if not needPropertData:
-                    changeSetDict[propertyName] = propertyData
+        changeSetDict['branch'] = branch
+
+        changeset_info_items = changeset_raw.split("\n\n\n\n")
+        changeset_items = list()
+
+        for changeset_info_item in changeset_info_items:
+            if any(changeset_info_item.startswith(keyword) for keyword in ['Changeset', 'User', 'Date']):
+                changeset_info_item = changeset_info_item.split('\n\n')
+                changeset_items.extend(changeset_info_item)
             else:
-                index = split.find("$")
-                propertyName = split[:index].strip()
-                propertyData = split[index - 1:].strip()
-                itemsDict[propertyName] = propertyData
+                changeset_info_item = changeset_info_item.replace('\n\n', '\n')
+                changeset_items.append(changeset_info_item)
+
+        for changeset_item in changeset_items:
+            for item in pattern.finditer(changeset_item):
+                propertyName, propertyData = item.groups()
+                propertyName = propertyName.lstrip().rstrip().replace(' ', '_').lower()
+                propertyData = propertyData.lstrip().rstrip()
+
+                changeSetDict[propertyName] = propertyData
+
+                if propertyName == 'items':
+                    for i in propertyData.split('\n'):
+                        i = i.lstrip().rstrip()
+                        action, filename = i.split(' ', maxsplit=1)
+                        action = action.lstrip().rstrip()
+                        filename = filename.lstrip().rstrip()
+                        itemsDict[action] = filename
+                    changeSetDict['items'] = itemsDict
+
+        changeSetList.append(changeSetDict)
 
-    changeSetDict["items"] = itemsDict
-    changeSetList.append(changeSetDict)
     return changeSetList
 
 
@@ -496,7 +502,7 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
 
         items = changeSet['items']
         # print(changeSet)
-        changesetId = changeSet.get('Changeset')
+        changesetId = changeSet.get('changeset')
         if changesetId is None:
             value = changeSet.get('edit')
             if value is not None:
@@ -506,7 +512,7 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             else:
                 raise Exception("changesetId is not set")
 
-        date = changeSet['Date']
+        date = changeSet['date']
 
         for key in items:
             if ';' in key:
@@ -578,18 +584,18 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             'parents': [],
             'date': date,
             'branches': [changeSet['branch']],
-            'message': changeSet.get('Comment'),
+            'message': changeSet.get('comment'),
             'removed': removed,
             'renamed': renamed
         }
 
         commit['author'] = {
             'date': date,
-            'name': changeSet['User'],
+            'name': changeSet['user'],
         }
         commit['committer'] = {
             'date': date,
-            'name': changeSet['User']
+            'name': changeSet['user']
         }
 
         commits.append(commit)
@@ -834,7 +840,8 @@ def performSync(branch, shelvet, force=False, isBlameRequired=True, shouldRunRes
     logging.debug("Total {} seconds".format(end_time - start_time))
 
 
-if __name__ == "__main__":
+def appsurifytfs(*args):
+    global login_details
     logging.info("Start with args: {}".format(" ".join(sys.argv)))
     if "sync" in sys.argv:
         remotes = force = False
@@ -876,46 +883,5 @@ if __name__ == "__main__":
         except Exception as e:
             logging.error(e, exc_info=True)
 
-
-
-def appsurifytfs(*args):
-    logging.info("Start with args: {}".format(" ".join(sys.argv)))
-    if "sync" in sys.argv:
-        remotes = force = False
-        blame = True
-        numberOfChangets = None
-        shouldRunRestApi = False
-        branch = ''
-        shelvet = ''
-
-        if '-f' in sys.argv:
-            force = True
-        if '--no-blame' in sys.argv:
-            blame = False
-        if '--set_last_changeset_id' in sys.argv:
-            index = sys.argv.index('--set_last_changeset_id')
-            numberOfChangets = sys.argv[index + 1]
-        if '-runApi' in sys.argv:
-            shouldRunRestApi = True
-        if '-branch' in sys.argv:
-            index = sys.argv.index('-branch')
-            branch = sys.argv[index + 1]
-        if '-shelvet' in sys.argv:
-            index = sys.argv.index('-shelvet')
-            shelvet = sys.argv[index + 1]
-        if '-shelveset' in sys.argv:
-            index = sys.argv.index('-shelveset')
-            shelvet = sys.argv[index + 1]
-        if '-path' in sys.argv:
-            index = sys.argv.index('-path')
-            path = sys.argv[index + 1]
-
-        if '-login' in sys.argv:
-            index = sys.argv.index('-login')
-            login = sys.argv[index + 1]
-            login_details = " /loginType:OAuth /login:.,"+login
-
-        try:
-            performSync(branch, shelvet, force=force, isBlameRequired=blame, shouldRunRestApi=shouldRunRestApi, numberOfChangets=numberOfChangets)
-        except Exception as e:
-            logging.error(e, exc_info=True)
\ No newline at end of file
+if __name__ == "__main__":
+    appsurifytfs(sys.argv)
\ No newline at end of file
